/**
 * (C) Copyright IBM Corp. 2022.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/// <reference types="node" />
import { IncomingHttpHeaders, OutgoingHttpHeaders } from 'http';
import { BaseService, UserOptions } from 'ibm-cloud-sdk-core';
/**
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * API Version: 1.0
 */
declare class EventNotificationsV1 extends BaseService {
    static DEFAULT_SERVICE_URL: string;
    static DEFAULT_SERVICE_NAME: string;
    /*************************
     * Factory method
     ************************/
    /**
     * Constructs an instance of EventNotificationsV1 with passed in options and external configuration.
     *
     * @param {UserOptions} [options] - The parameters to send to the service.
     * @param {string} [options.serviceName] - The name of the service to configure
     * @param {Authenticator} [options.authenticator] - The Authenticator object used to authenticate requests to the service
     * @param {string} [options.serviceUrl] - The URL for the service
     * @returns {EventNotificationsV1}
     */
    static newInstance(options: UserOptions): EventNotificationsV1;
    /**
     * Construct a EventNotificationsV1 object.
     *
     * @param {Object} options - Options for the service.
     * @param {string} [options.serviceUrl] - The base url to use when contacting the service. The base url may differ between IBM Cloud regions.
     * @param {OutgoingHttpHeaders} [options.headers] - Default headers that shall be included with every request to the service.
     * @param {Authenticator} options.authenticator - The Authenticator object used to authenticate requests to the service
     * @constructor
     * @returns {EventNotificationsV1}
     */
    constructor(options: UserOptions);
    /*************************
     * sendNotifications
     ************************/
    /**
     * Send a notification.
     *
     * Send a notification.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.subject - The Notifications subject.
     * @param {string} params.severity - The Notifications severity.
     * @param {string} params.id - The Notifications id.
     * @param {string} params.source - The source of Notifications.
     * @param {string} params.enSourceId - The Event Notifications source id.
     * @param {string} params.type - The Notifications type.
     * @param {string} params.time - The Notifications time.
     * @param {JsonObject} [params.data] - The Notifications data for webhook.
     * @param {NotificationDevices} [params.pushTo] - Payload describing a FCM Notifications targets.
     * @param {NotificationFCMBody} [params.messageFcmBody] -
     * @param {JsonObject} [params.messageApnsHeaders] - The attributes for an FCM/APNs notification.
     * @param {NotificationAPNSBody} [params.messageApnsBody] - Payload describing a APNs Notifications body.
     * @param {string} [params.datacontenttype] - The Notifications content type.
     * @param {string} [params.specversion] - The Notifications specversion.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.NotificationResponse>>}
     */
    sendNotifications(params: EventNotificationsV1.SendNotificationsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.NotificationResponse>>;
    /*************************
     * sources
     ************************/
    /**
     * List all Sources.
     *
     * List all Sources.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.SourceList>>}
     */
    listSources(params: EventNotificationsV1.ListSourcesParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.SourceList>>;
    /**
     * Get a Source.
     *
     * Get a Sources.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Source.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Source>>}
     */
    getSource(params: EventNotificationsV1.GetSourceParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Source>>;
    /*************************
     * topics
     ************************/
    /**
     * Create a new Topic.
     *
     * Create a new Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.name - Name of the topic.
     * @param {string} [params.description] - Description of the topic.
     * @param {TopicUpdateSourcesItem[]} [params.sources] - List of sources.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicResponse>>}
     */
    createTopic(params: EventNotificationsV1.CreateTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicResponse>>;
    /**
     * List all Topics.
     *
     * List all Topics.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicList>>}
     */
    listTopics(params: EventNotificationsV1.ListTopicsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicList>>;
    /**
     * Get details of a Topic.
     *
     * Get details of a Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Topic.
     * @param {string} [params.include] - Include sub topics.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>}
     */
    getTopic(params: EventNotificationsV1.GetTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>;
    /**
     * Update details of a Topic.
     *
     * Update details of a Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Topic.
     * @param {string} [params.name] - Name of the topic.
     * @param {string} [params.description] - Description of the topic.
     * @param {TopicUpdateSourcesItem[]} [params.sources] - List of sources.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>}
     */
    replaceTopic(params: EventNotificationsV1.ReplaceTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>;
    /**
     * Delete a Topic.
     *
     * Delete a Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Topic.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteTopic(params: EventNotificationsV1.DeleteTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /*************************
     * destinations
     ************************/
    /**
     * Create a new Destination.
     *
     * Create a new Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.name - The Destintion name.
     * @param {string} params.type - The type of Destination Webhook.
     * @param {string} [params.description] - The Destination description.
     * @param {DestinationConfig} [params.config] - Payload describing a destination configuration.
     * @param {NodeJS.ReadableStream | Buffer} [params.certificate] - Certificate for APNS.
     * @param {string} [params.certificateContentType] - The content type of certificate.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationResponse>>}
     */
    createDestination(params: EventNotificationsV1.CreateDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationResponse>>;
    /**
     * List all Destinations.
     *
     * List all Destinations.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationList>>}
     */
    listDestinations(params: EventNotificationsV1.ListDestinationsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationList>>;
    /**
     * Get details of a Destination.
     *
     * Get details of a Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>}
     */
    getDestination(params: EventNotificationsV1.GetDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>;
    /**
     * Update details of a Destination.
     *
     * Update details of a Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {string} [params.name] - Destination name.
     * @param {string} [params.description] - Destination description.
     * @param {DestinationConfig} [params.config] - Payload describing a destination configuration.
     * @param {NodeJS.ReadableStream | Buffer} [params.certificate] - Certificate for APNS.
     * @param {string} [params.certificateContentType] - The content type of certificate.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>}
     */
    updateDestination(params: EventNotificationsV1.UpdateDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>;
    /**
     * Delete a Destination.
     *
     * Delete a Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteDestination(params: EventNotificationsV1.DeleteDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /*************************
     * destinationsPushDevices
     ************************/
    /**
     * Get list of Destination devices.
     *
     * Get list of Destination devices.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationDevicesList>>}
     */
    listDestinationDevices(params: EventNotificationsV1.ListDestinationDevicesParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationDevicesList>>;
    /**
     * Retrieves report of destination devices registered.
     *
     * Retrieves report of destination devices registered.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {number} [params.days] - Number of days report has to be generated from
     * * `Note :` Max value is 90
     * * Min or default value is 1.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationDevicesReport>>}
     */
    getDestinationDevicesReport(params: EventNotificationsV1.GetDestinationDevicesReportParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationDevicesReport>>;
    /*************************
     * destinationTagsSubscriptions
     ************************/
    /**
     * List all Tag Subscriptions for a device.
     *
     * List all Tag Subscriptions for a device.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {string} params.deviceId - DeviceID of the destination.
     * @param {string} [params.tagName] - TagName of the subscription.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.TagsSubscriptionList>>}
     */
    listTagsSubscriptionsDevice(params: EventNotificationsV1.ListTagsSubscriptionsDeviceParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.TagsSubscriptionList>>;
    /**
     * List all Tag Subscriptions.
     *
     * List all Tag Subscriptions.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {string} [params.deviceId] - DeviceID of the destination tagsubscription.
     * @param {string} [params.userId] - UserID of the destination.
     * @param {string} [params.tagName] - TagName of the subscription.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.TagsSubscriptionList>>}
     */
    listTagsSubscription(params: EventNotificationsV1.ListTagsSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.TagsSubscriptionList>>;
    /**
     * Create a new Tag subscription.
     *
     * Create a new Tag subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {string} params.deviceId - Unique identifier of the device.
     * @param {string} params.tagName - The name of the tag its subscribed.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationTagsSubscriptionResponse>>}
     */
    createTagsSubscription(params: EventNotificationsV1.CreateTagsSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationTagsSubscriptionResponse>>;
    /**
     * Delete a Tag subcription.
     *
     * Delete a Tag subcription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {string} [params.deviceId] - DeviceID of the destination tagsubscription.
     * @param {string} [params.tagName] - TagName of the subscription.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteTagsSubscription(params: EventNotificationsV1.DeleteTagsSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /*************************
     * subscriptions
     ************************/
    /**
     * Create a new Subscription.
     *
     * Create a new Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.name - Subscription name.
     * @param {string} params.destinationId - Destination ID.
     * @param {string} params.topicId - Topic ID.
     * @param {string} [params.description] - Subscription description.
     * @param {SubscriptionCreateAttributes} [params.attributes] -
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>}
     */
    createSubscription(params: EventNotificationsV1.CreateSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>;
    /**
     * List all Subscriptions.
     *
     * List all Subscriptions.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.SubscriptionList>>}
     */
    listSubscriptions(params: EventNotificationsV1.ListSubscriptionsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.SubscriptionList>>;
    /**
     * Get details of a Subscription.
     *
     * Get details of a Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Subscription.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>}
     */
    getSubscription(params: EventNotificationsV1.GetSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>;
    /**
     * Delete a Subscription.
     *
     * Delete a Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Subscription.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteSubscription(params: EventNotificationsV1.DeleteSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /**
     * Update details of a Subscription.
     *
     * Update details of a Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Subscription.
     * @param {string} [params.name] - Name of the subscription.
     * @param {string} [params.description] - Description of the subscription.
     * @param {SubscriptionUpdateAttributes} [params.attributes] -
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>}
     */
    updateSubscription(params: EventNotificationsV1.UpdateSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>;
}
/*************************
 * interfaces
 ************************/
declare namespace EventNotificationsV1 {
    /** An operation response. */
    interface Response<T = any> {
        result: T;
        status: number;
        statusText: string;
        headers: IncomingHttpHeaders;
    }
    /** The callback for a service request. */
    type Callback<T> = (error: any, response?: Response<T>) => void;
    /** The body of a service request that returns no response data. */
    interface Empty {
    }
    /** A standard JS object, defined to avoid the limitations of `Object` and `object` */
    interface JsonObject {
        [key: string]: any;
    }
    /*************************
     * request interfaces
     ************************/
    /** Parameters for the `sendNotifications` operation. */
    interface SendNotificationsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** The Notifications subject. */
        subject: string;
        /** The Notifications severity. */
        severity: string;
        /** The Notifications id. */
        id: string;
        /** The source of Notifications. */
        source: string;
        /** The Event Notifications source id. */
        enSourceId: string;
        /** The Notifications type. */
        type: string;
        /** The Notifications time. */
        time: string;
        /** The Notifications data for webhook. */
        data?: JsonObject;
        /** Payload describing a FCM Notifications targets. */
        pushTo?: NotificationDevices;
        messageFcmBody?: NotificationFCMBody;
        /** The attributes for an FCM/APNs notification. */
        messageApnsHeaders?: JsonObject;
        /** Payload describing a APNs Notifications body. */
        messageApnsBody?: NotificationAPNSBody;
        /** The Notifications content type. */
        datacontenttype?: string;
        /** The Notifications specversion. */
        specversion?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listSources` operation. */
    interface ListSourcesParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getSource` operation. */
    interface GetSourceParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Source. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createTopic` operation. */
    interface CreateTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Name of the topic. */
        name: string;
        /** Description of the topic. */
        description?: string;
        /** List of sources. */
        sources?: TopicUpdateSourcesItem[];
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listTopics` operation. */
    interface ListTopicsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getTopic` operation. */
    interface GetTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Topic. */
        id: string;
        /** Include sub topics. */
        include?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `replaceTopic` operation. */
    interface ReplaceTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Topic. */
        id: string;
        /** Name of the topic. */
        name?: string;
        /** Description of the topic. */
        description?: string;
        /** List of sources. */
        sources?: TopicUpdateSourcesItem[];
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteTopic` operation. */
    interface DeleteTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Topic. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createDestination` operation. */
    interface CreateDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** The Destintion name. */
        name: string;
        /** The type of Destination Webhook. */
        type: CreateDestinationConstants.Type | string;
        /** The Destination description. */
        description?: string;
        /** Payload describing a destination configuration. */
        config?: DestinationConfig;
        /** Certificate for APNS. */
        certificate?: NodeJS.ReadableStream | Buffer;
        /** The content type of certificate. */
        certificateContentType?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Constants for the `createDestination` operation. */
    namespace CreateDestinationConstants {
        /** The type of Destination Webhook. */
        enum Type {
            WEBHOOK = "webhook",
            PUSH_ANDROID = "push_android",
            PUSH_IOS = "push_ios"
        }
    }
    /** Parameters for the `listDestinations` operation. */
    interface ListDestinationsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getDestination` operation. */
    interface GetDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `updateDestination` operation. */
    interface UpdateDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** Destination name. */
        name?: string;
        /** Destination description. */
        description?: string;
        /** Payload describing a destination configuration. */
        config?: DestinationConfig;
        /** Certificate for APNS. */
        certificate?: NodeJS.ReadableStream | Buffer;
        /** The content type of certificate. */
        certificateContentType?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteDestination` operation. */
    interface DeleteDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listDestinationDevices` operation. */
    interface ListDestinationDevicesParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getDestinationDevicesReport` operation. */
    interface GetDestinationDevicesReportParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** Number of days report has to be generated from * `Note :` Max value is 90 * Min or default value is 1. */
        days?: number;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listTagsSubscriptionsDevice` operation. */
    interface ListTagsSubscriptionsDeviceParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** DeviceID of the destination. */
        deviceId: string;
        /** TagName of the subscription. */
        tagName?: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listTagsSubscription` operation. */
    interface ListTagsSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** DeviceID of the destination tagsubscription. */
        deviceId?: string;
        /** UserID of the destination. */
        userId?: string;
        /** TagName of the subscription. */
        tagName?: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createTagsSubscription` operation. */
    interface CreateTagsSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** Unique identifier of the device. */
        deviceId: string;
        /** The name of the tag its subscribed. */
        tagName: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteTagsSubscription` operation. */
    interface DeleteTagsSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** DeviceID of the destination tagsubscription. */
        deviceId?: string;
        /** TagName of the subscription. */
        tagName?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createSubscription` operation. */
    interface CreateSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Subscription name. */
        name: string;
        /** Destination ID. */
        destinationId: string;
        /** Topic ID. */
        topicId: string;
        /** Subscription description. */
        description?: string;
        attributes?: SubscriptionCreateAttributes;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listSubscriptions` operation. */
    interface ListSubscriptionsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** offset for paginated results. */
        offset?: number;
        /** Page limit for paginated results. */
        limit?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getSubscription` operation. */
    interface GetSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Subscription. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteSubscription` operation. */
    interface DeleteSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Subscription. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `updateSubscription` operation. */
    interface UpdateSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Subscription. */
        id: string;
        /** Name of the subscription. */
        name?: string;
        /** Description of the subscription. */
        description?: string;
        attributes?: SubscriptionUpdateAttributes;
        headers?: OutgoingHttpHeaders;
    }
    /*************************
     * model interfaces
     ************************/
    /** Payload describing a destination get request. */
    interface Destination {
        /** Destination ID. */
        id: string;
        /** Destination name. */
        name: string;
        /** Destination description. */
        description: string;
        /** Destination type Email/SMS/Webhook/FCM. */
        type: string;
        /** Payload describing a destination configuration. */
        config?: DestinationConfig;
        /** Last updated time. */
        updated_at: string;
        /** Number of subscriptions. */
        subscription_count: number;
        /** List of subscriptions. */
        subscription_names: string[];
    }
    /** Payload describing a destination configuration. */
    interface DestinationConfig {
        params: DestinationConfigParams;
    }
    /** DestinationConfigParams. */
    interface DestinationConfigParams {
    }
    /** Payload describing a destination devices list request. */
    interface DestinationDevicesList {
        /** Total number of destination devices. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show destination devices. */
        limit: number;
        /** List of devices. */
        devices: DestinationDevicesListItem[];
    }
    /** device object. */
    interface DestinationDevicesListItem {
        /** device ID. */
        id: string;
        /** user ID. */
        user_id?: string;
        /** Destination platform. */
        platform: string;
        /** Destination device token. */
        token: string;
        /** Updated at. */
        updated_at: string;
    }
    /** Payload describing a destination devices report. */
    interface DestinationDevicesReport {
        /** Android Devices Registered. */
        android: number;
        /** ios Devices Registered. */
        ios: number;
        /** chrome web Devices Registered. */
        chrome: number;
        /** firefox web Devices Registered. */
        firefox: number;
        /** safari web Devices Registered. */
        safari: number;
        /** chromeAppExt Devices Registered. */
        chromeAppExt: number;
        /** Total Devices Registered. */
        all: number;
    }
    /** Payload describing a destination list request. */
    interface DestinationList {
        /** Total number of destinations. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show destinations. */
        limit: number;
        /** List of destinations. */
        destinations: DestinationListItem[];
    }
    /** Destination object. */
    interface DestinationListItem {
        /** Destination ID. */
        id: string;
        /** Destination name. */
        name: string;
        /** Destination description. */
        description: string;
        /** Destination type Email/SMS/Webhook. */
        type: string;
        /** Subscription count. */
        subscription_count: number;
        /** Names of subscriptions. */
        subscription_names: string[];
        /** Updated at. */
        updated_at: string;
    }
    /** Payload describing a destination get request. */
    interface DestinationResponse {
        /** Destination ID. */
        id: string;
        /** Destination name. */
        name: string;
        /** Destination description. */
        description: string;
        /** Destination type Email/SMS/Webhook. */
        type: string;
        /** Payload describing a destination configuration. */
        config: DestinationConfig;
        /** Last updated time. */
        created_at: string;
    }
    /** Payload describing a destination get request. */
    interface DestinationTagsSubscriptionResponse {
        /** Subscription Tag ID. */
        id: string;
        /** Unique identifier of the device. */
        device_id: string;
        /** The name of the tag its subscribed. */
        tag_name: string;
        /** The user identifier for the the device registration. */
        user_id?: string;
        /** Last updated time. */
        created_at: string;
    }
    /** The email ids. */
    interface EmailUpdateAttributesTo {
        /** The email ids. */
        add?: string[];
        /** The email ids for removal. */
        remove?: string[];
    }
    /** The email ids. */
    interface EmailUpdateAttributesUnsubscribed {
        /** The email ids unsubscribed. */
        remove?: string[];
    }
    /** Allows setting the notification LED color on receiving push notification . */
    interface Lights {
        /** The color of the led. The hardware will do its best approximation. */
        led_argb?: string;
        /** The number of milliseconds for the LED to be on while it's flashing. The hardware will do its best
         *  approximation.
         */
        led_on_ms?: number;
        /** The number of milliseconds for the LED to be off while it's flashing. The hardware will do its best
         *  approximation.
         */
        led_off_ms?: string;
    }
    /** Payload describing a APNs Notifications body. */
    interface NotificationAPNSBody {
        /** NotificationAPNSBody accepts additional properties. */
        [propName: string]: any;
    }
    /** Payload describing a apns notifications body message Data. */
    interface NotificationAPNSBodyMessageData {
        /** The notification message to be shown to the user. */
        alert: string;
        /** The number to display as the badge of the application icon. */
        badge?: number;
        /** The category identifier to be used for the interactive push notifications. */
        interactiveCategory?: string;
        /** The title for the Action key. */
        iosActionKey?: string;
        /** Custom JSON payload that will be sent as part of the notification message. */
        payload?: JsonObject;
        /** The name of the sound file in the application bundle. The sound of this file is played as an alert. */
        sound?: string;
        /** The key to a title string in the Localizable.strings file for the current localization. The key string can
         *  be formatted with %@ and %n$@ specifiers to take the variables specified in the titleLocArgs array.
         */
        titleLocKey?: string;
        /** A key to an alert-message string in a Localizabl.strings file for the current localization (which is set by
         *  the userÃ¢â‚¬â„¢s language preference).
         *    The key string can be formatted with %@ and %n$@ specifiers to take the variables specified in the locArgs
         *  array.
         */
        locKey?: string;
        /** The filename of an image file in the app bundle, with or without the filename extension. The image is used
         *  as the launch image when users tap the action button or move the action slider.
         */
        launchImage?: string;
        /** Variable string values to appear in place of the format specifiers in title-loc-key. */
        titleLocArgs?: string[];
        /** Variable string values to appear in place of the format specifiers in locKey. */
        locArgs?: string[];
        /** The title of Rich Push notifications (Supported only on iOS 10 and above). */
        title?: string;
        /** The subtitle of the Rich Notifications.(Supported only on iOS 10 and above). */
        subtitle?: string;
        /** The link to the iOS notifications media (video, audio, GIF, images - Supported only on iOS 10 and above). */
        attachmentUrl?: string;
        type?: string;
        /** Multiple notifications with the same collapse identifier are displayed to the user as a single notification. */
        apnsCollapseId?: string;
        /** An app-specific identifier for grouping related notifications. This value corresponds to the
         *  threadIdentifier property in the UNNotificationContent object.
         */
        apnsThreadId?: string;
        /** The string the notification adds to the category's summary format string. */
        apnsGroupSummaryArg?: string;
        /** The number of items the notification adds to the category's summary format string. */
        apnsGroupSummaryArgCount?: number;
    }
    /** Payload describing a FCM Notifications targets. */
    interface NotificationDevices {
        /** List of FCM deviceIds. */
        fcm_devices?: string[];
        /** List of APNs deviceIds. */
        apns_devices?: string[];
        /** List of userIds. */
        user_ids?: string[];
        /** List of tags. */
        tags?: string[];
        /** List of platforms. */
        platforms?: string[];
    }
    /** NotificationFCMBody. */
    interface NotificationFCMBody {
        /** NotificationFCMBody accepts additional properties. */
        [propName: string]: any;
    }
    /** Payload describing a fcm notifications body message Data. */
    interface NotificationFCMBodyMessageData {
        /** The notification message to be shown to the user. */
        alert: string;
        /** Dozed devices to display only the latest notification and discard old low priority notifications. */
        collapse_key?: string;
        /** The category identifier to be used for the interactive push notifications. */
        interactive_category?: string;
        /** Specify the name of the icon to be displayed for the notification. Make sure the icon is already packaged
         *  with the client application.
         */
        icon?: string;
        /** When this parameter is set to true, it indicates that the
         *    message should not be sent until the device becomes active.
         */
        delay_while_idle?: boolean;
        /** Device group messaging makes it possible for every app instance in a group to reflect the latest messaging
         *  state.
         */
        sync?: boolean;
        /** private/public - Visibility of this notification, which affects how and when the notifications are revealed
         *  on a secure locked screen.
         */
        visibility?: string;
        /** Content specified will show up on a secure locked screen on the device when visibility is set to Private. */
        redact?: string;
        /** Custom JSON payload that will be sent as part of the notification message. */
        payload?: JsonObject;
        /** A string value that indicates the priority of this notification. Allowed values are 'max', 'high',
         *  'default', 'low' and 'min'. High/Max priority notifications along with 'sound' field may be used for Heads up
         *  notification in Android 5.0 or higher.sampleval='low'.
         */
        priority?: string;
        /** The sound file (on device) that will be attempted to play when the notification arrives on the device. */
        sound?: string;
        /** This parameter specifies how long (in seconds) the message
         *    should be kept in GCM storage if the device is offline.
         */
        time_to_live?: number;
        /** Allows setting the notification LED color on receiving push notification . */
        lights?: Lights;
        /** The title of Rich Push notifications. */
        android_title?: string;
        /** Set this notification to be part of a group of notifications sharing the same key. Grouped notifications may
         *  display in a cluster or stack on devices which support such rendering.
         */
        group_id?: string;
        /** Options to specify for Android expandable notifications. The types of expandable notifications are
         *  picture_notification, bigtext_notification, inbox_notification.
         */
        style?: Style;
        /** Notification type. */
        type?: string;
    }
    /** Payload describing a notifications response. */
    interface NotificationResponse {
        /** Notification ID. */
        notification_id: string;
        /** NotificationResponse accepts additional properties. */
        [propName: string]: any;
    }
    /** Rule object. */
    interface Rules {
        /** Whether the rule is enabled or not. */
        enabled?: boolean;
        /** Event type filter. */
        event_type_filter: string;
        /** Notification filter. */
        notification_filter?: string;
    }
    /** Rule object. */
    interface RulesGet {
        /** Whether the rule is enabled or not. */
        enabled: boolean;
        /** Event type filter. */
        event_type_filter: string;
        /** Notification filter. */
        notification_filter: string;
        /** Last time the topic was updated. */
        updated_at: string;
        /** Autogenerated rule ID. */
        id: string;
    }
    /** Payload describing a source generate request. */
    interface Source {
        /** The id of the source. */
        id: string;
        /** The name of the source. */
        name: string;
        /** The description of the source. */
        description: string;
        /** The status of the source. */
        enabled: boolean;
        /** Type of the source. */
        type: string;
        /** The last updated time of the source. */
        updated_at: string;
        /** The number of topics. */
        topic_count: number;
        /** The names of the topics. */
        topic_names: string[];
    }
    /** Payload describing a source list request. */
    interface SourceList {
        /** Number of sources. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show sources. */
        limit: number;
        /** List of sources. */
        sources: SourceListItem[];
    }
    /** Payload describing a source list item. */
    interface SourceListItem {
        /** ID of the source. */
        id: string;
        /** Name of the source. */
        name: string;
        /** Description of the source. */
        description: string;
        /** Type of the source. */
        type: string;
        /** Whether the source is enabled or not. */
        enabled: boolean;
        /** Time of the last update. */
        updated_at: string;
        /** Number of topics. */
        topic_count: number;
    }
    /** SourcesListItem. */
    interface SourcesListItem {
        /** ID of the source. */
        id: string;
        /** Name of the source. */
        name: string;
        /** List of rules. */
        rules: RulesGet[];
    }
    /** Options to specify for Android expandable notifications. The types of expandable notifications are picture_notification, bigtext_notification, inbox_notification. */
    interface Style {
        /** Specifies the type of expandable notifications.  The possible values are bigtext_notification,
         *  picture_notification, inbox_notification.
         */
        type?: string;
        /** Specifies the title of the notification.  The title is displayed when the notification is expanded.  Title
         *  must be specified for all three expandable notification.
         */
        title?: string;
        /** An URL from which the picture has to be obtained for the notification.  Must be specified for
         *  picture_notification.
         */
        url?: string;
        /** The big text that needs to be displayed on expanding a bigtext_notification.  Must be specified for
         *  bigtext_notification.
         */
        text?: string;
        /** An array of strings that is to be displayed in inbox style for inbox_notification.  Must be specified for
         *  inbox_notification.
         */
        lines?: string[];
        /** Style accepts additional properties. */
        [propName: string]: any;
    }
    /** Subscription object. */
    interface Subscription {
        /** Subscription ID. */
        id: string;
        /** Subscription name. */
        name: string;
        /** Subscription description. */
        description: string;
        /** Last updated time. */
        updated_at: string;
        /** From Email ID (it will be displayed only in case of smtp_ibm destination type). */
        from?: string;
        /** The type of destination. */
        destination_type: string;
        /** The destination ID. */
        destination_id: string;
        /** The destination name. */
        destination_name: string;
        /** Topic ID. */
        topic_id: string;
        /** Topic name. */
        topic_name: string;
        attributes?: SubscriptionAttributes;
        /** Subscription accepts additional properties. */
        [propName: string]: any;
    }
    /** SubscriptionAttributes. */
    interface SubscriptionAttributes {
        /** SubscriptionAttributes accepts additional properties. */
        [propName: string]: any;
    }
    /** SubscriptionCreateAttributes. */
    interface SubscriptionCreateAttributes {
    }
    /** Subscription list object. */
    interface SubscriptionList {
        /** Number of subscriptions. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show subscriptions. */
        limit: number;
        /** List of subscriptions. */
        subscriptions: SubscriptionListItem[];
    }
    /** Subscription list item. */
    interface SubscriptionListItem {
        /** ID of the subscription. */
        id: string;
        /** Name of the subscription. */
        name: string;
        /** Description of the subscription. */
        description: string;
        /** ID of the destination. */
        destination_id: string;
        /** Name of the destination. */
        destination_name?: string;
        /** The type of destination. */
        destination_type: string;
        /** ID of the topic. */
        topic_id: string;
        /** Name of the topic. */
        topic_name?: string;
        /** Last updated time of the subscription. */
        updated_at: string;
    }
    /** SubscriptionUpdateAttributes. */
    interface SubscriptionUpdateAttributes {
    }
    /** Payload describing a tags list request. */
    interface TagsSubscriptionList {
        /** Total number of tags. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show tags. */
        limit: number;
        /** List of tags. */
        tag_subscriptions: TagsSubscriptionListItem[];
    }
    /** Tags subscription object. */
    interface TagsSubscriptionListItem {
        /** Subscription Tag ID. */
        id: string;
        /** Unique identifier of the device. */
        device_id: string;
        /** The name of the tag its subscribed. */
        tag_name: string;
        /** The user identifier for the the device registration. */
        user_id?: string;
        /** Updated at. */
        updated_at: string;
    }
    /** Topic object. */
    interface Topic {
        /** Autogenerated topic ID. */
        id: string;
        /** Description of the topic. */
        description: string;
        /** Name of the topic. */
        name: string;
        /** Last time the topic was updated. */
        updated_at: string;
        /** Number of sources. */
        source_count: number;
        /** List of sources. */
        sources: SourcesListItem[];
        /** Number of subscriptions. */
        subscription_count: number;
        /** List of subscriptions. */
        subscriptions: SubscriptionListItem[];
    }
    /** Topic list object. */
    interface TopicList {
        /** Number of topics. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show subscriptions. */
        limit: number;
        /** List of topics. */
        topics: TopicsListItem[];
    }
    /** Topic object. */
    interface TopicResponse {
        /** Autogenerated topic ID. */
        id: string;
        /** Name of the topic. */
        name: string;
        /** Description of the topic. */
        description: string;
        /** Last time the topic was updated. */
        created_at: string;
    }
    /** TopicUpdateSourcesItem. */
    interface TopicUpdateSourcesItem {
        /** ID of the source. */
        id: string;
        /** List of rules. */
        rules: Rules[];
    }
    /** Topic list item object. */
    interface TopicsListItem {
        /** Autogenerated topic ID. */
        id: string;
        /** Name of the topic. */
        name: string;
        /** Description of the topic. */
        description: string;
        /** Number of sources. */
        source_count: number;
        /** List of source names. */
        sources_names: string[];
        /** Number of subscriptions. */
        subscription_count: number;
    }
    /** Payload describing a FCM destination configuration. */
    interface DestinationConfigParamsFCMDestinationConfig extends DestinationConfigParams {
        /** FCM server_key. */
        server_key: string;
        /** FCM sender_id. */
        sender_id: string;
    }
    /** Payload describing a IOS destination configuration. */
    interface DestinationConfigParamsIOSDestinationConfig extends DestinationConfigParams {
        /** Authentication type (p8 or p12). */
        cert_type: string;
        /** Sandbox mode for IOS destinations. */
        is_sandbox: boolean;
        /** Password for certificate (Required when cert_type is p12). */
        password?: string;
        /** Key ID for token (Required when cert_type is p8). */
        key_id?: string;
        /** Team ID for token (Required when cert_type is p8). */
        team_id?: string;
        /** Bundle ID for token (Required when cert_type is p8). */
        bundle_id?: string;
    }
    /** Payload describing a webhook destination configuration. */
    interface DestinationConfigParamsWebhookDestinationConfig extends DestinationConfigParams {
        /** URL of webhook. */
        url: string;
        /** HTTP method of webhook. */
        verb: string;
        /** Custom headers (Key-Value pair) for webhook call. */
        custom_headers?: JsonObject;
        /** List of sensitive headers from custom headers. */
        sensitive_headers?: string[];
    }
    /** Payload describing a fcm notifications body message. */
    interface NotificationAPNSBodyMessageENData extends NotificationAPNSBody {
        /** Payload describing a apns notifications body message Data. */
        en_data?: NotificationAPNSBodyMessageData;
    }
    /** The attributes for an FCM/APNs notification. */
    interface NotificationAPNSBodyNotificationPayload extends NotificationAPNSBody {
    }
    /** Payload describing a fcm notifications body message. */
    interface NotificationFCMBodyMessageENData extends NotificationFCMBody {
        /** Payload describing a fcm notifications body message Data. */
        en_data?: NotificationFCMBodyMessageData;
    }
    /** The attributes for an FCM/APNs notification. */
    interface NotificationFCMBodyNotificationPayload extends NotificationFCMBody {
    }
    /** The attributes reponse for an email destination. */
    interface SubscriptionAttributesEmailAttributesResponse extends SubscriptionAttributes {
    }
    /** SMS attributes object. */
    interface SubscriptionAttributesSMSAttributesResponse extends SubscriptionAttributes {
    }
    /** The attributes for a webhook notification. */
    interface SubscriptionAttributesWebhookAttributesResponse extends SubscriptionAttributes {
        /** Signing webhook attributes. */
        signing_enabled: boolean;
        /** Decision for Notification Payload to be added. */
        add_notification_payload: boolean;
    }
    /** The attributes for an email notification. */
    interface SubscriptionCreateAttributesEmailAttributes extends SubscriptionCreateAttributes {
        /** The email id string. */
        to: string[];
        /** Whether to add the notification payload to the email. */
        add_notification_payload: boolean;
        /** The email address to reply to. */
        reply_to_mail: string;
        /** The email name to reply to. */
        reply_to_name: string;
        /** The email name of From. */
        from_name: string;
    }
    /** The attributes for an FCM notification. */
    interface SubscriptionCreateAttributesFCMAttributes extends SubscriptionCreateAttributes {
    }
    /** SMS attributes object. */
    interface SubscriptionCreateAttributesSMSAttributes extends SubscriptionCreateAttributes {
        /** The phone number to send the SMS to. */
        to: string[];
    }
    /** The attributes for a webhook notification. */
    interface SubscriptionCreateAttributesWebhookAttributes extends SubscriptionCreateAttributes {
        /** Signing webhook attributes. */
        signing_enabled: boolean;
    }
    /** The attributes for an email notification. */
    interface SubscriptionUpdateAttributesEmailUpdateAttributes extends SubscriptionUpdateAttributes {
        /** The email ids. */
        to: EmailUpdateAttributesTo;
        /** Whether to add the notification payload to the email. */
        add_notification_payload: boolean;
        /** The email address to reply to. */
        reply_to_mail: string;
        /** The email name to reply to. */
        reply_to_name: string;
        /** The email name of From. */
        from_name: string;
        /** The email ids invited. */
        invited?: string[];
        /** The email ids. */
        unsubscribed?: EmailUpdateAttributesUnsubscribed;
    }
    /** SMS attributes object. */
    interface SubscriptionUpdateAttributesSMSAttributes extends SubscriptionUpdateAttributes {
        /** The phone number to send the SMS to. */
        to: string[];
    }
    /** The attributes for a webhook notification. */
    interface SubscriptionUpdateAttributesWebhookAttributes extends SubscriptionUpdateAttributes {
        /** Signing webhook attributes. */
        signing_enabled: boolean;
    }
}
export = EventNotificationsV1;
